summaryrefslogtreecommitdiffstats
path: root/src/groupview.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/groupview.h')
-rw-r--r--src/groupview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/groupview.h b/src/groupview.h
index 40a40f9..78a1909 100644
--- a/src/groupview.h
+++ b/src/groupview.h
@@ -47,10 +47,10 @@ public:
/**
* The constructor sets up the single column, and initializes the popup menu.
*
* @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/
- GroupView(TQWidget* tqparent, const char* name=0);
+ GroupView(TQWidget* parent, const char* name=0);
/**
* Returns the name of the field by which the entries are grouped
@@ -47,10 +47,10 @@ public:
* The constructor sets up the single column, and initializes the popup menu.
*
- * @param tqparent A pointer to the tqparent widget
+ * @param parent A pointer to the parent widget
* @param name The widget name
*/